spannertools.TrillSpanner
=========================

.. abjad-lineage:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner

.. autoclass:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.append
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.append_left
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.attach
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.components
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.detach
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.extend
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.extend_left
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.fracture
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.fuse
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.get_duration
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.get_timespan
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.index
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.leaves
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.override
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.pitch
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.pop
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.pop_left
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.set
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.written_pitch
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__call__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__contains__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__copy__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__eq__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__getitem__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__len__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__lt__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__ne__
      ~abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__repr__

Bases
-----

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.override
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.set
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.pitch
   :noindex:

.. autoattribute:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.written_pitch
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.attach
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.pop_left
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__call__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.TrillSpanner.TrillSpanner.TrillSpanner.__repr__
   :noindex:
